.. django-dashboards documentation master file, created by
   sphinx-quickstart on Thu Oct 27 14:05:56 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to django-dashboards's documentation!
=============================================

django-dashboards is a set of django applications to help you make data driven solutions.
Currently, included are:

* :doc:`dashboards <dashboards/index>`: For creating visual representations of your data to the end user.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   dashboards/index.rst
   api/modules.rst
   contributing.rst
   changelog.rst
